summaryrefslogtreecommitdiff
path: root/log.c
diff options
context:
space:
mode:
authorUwe Hermann <uwe@hermann-uwe.de>2012-02-29 22:32:34 +0100
committerUwe Hermann <uwe@hermann-uwe.de>2012-03-02 02:25:42 +0100
commit41a5d9624022856f4ef357c1fdce041a9774a99c (patch)
treee369327844ccc9f0731efa660979bdae9a77fb3d /log.c
parent4c1d067068fdb9e5f723b3548bddb64e0b06fc36 (diff)
downloadlibsigrokdecode-41a5d9624022856f4ef357c1fdce041a9774a99c.tar.gz
libsigrokdecode-41a5d9624022856f4ef357c1fdce041a9774a99c.zip
sr: Name all callback data 'cb_data'.
Diffstat (limited to 'log.c')
-rw-r--r--log.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/log.c b/log.c
index d8e98ba..dda689b 100644
--- a/log.c
+++ b/log.c
@@ -27,7 +27,7 @@
static int srd_loglevel = SRD_LOG_WARN; /* Show errors+warnings per default. */
/* Function prototype. */
-static int srd_logv(void *user_data, int loglevel, const char *format,
+static int srd_logv(void *cb_data, int loglevel, const char *format,
va_list args);
/* Pointer to the currently selected log handler. Default: srd_logv(). */
@@ -130,26 +130,26 @@ SRD_API char *srd_log_logdomain_get(void)
*
* @param handler Function pointer to the log handler function to use.
* Must not be NULL.
* @param user_data Pointer to private data to be passed on. This can be used
* by the caller to pass arbitrary data to the log functions.
* This pointer is only stored or passed on by libsigrokdecode,
* and is never used or interpreted in any way. The pointer
* is allowed to be NULL if the caller doesn't need/want to
* pass any data.
*
* @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
*/
-SRD_API int srd_log_handler_set(srd_log_handler_t handler, void *user_data)
+SRD_API int srd_log_handler_set(srd_log_handler_t handler, void *cb_data)
{
if (!handler) {
srd_err("log: %s: handler was NULL", __func__);
return SRD_ERR_ARG;
}
/* Note: 'user_data' is allowed to be NULL. */
srd_log_handler = handler;
- srd_log_handler_data = user_data;
+ srd_log_handler_data = cb_data;
return SRD_OK;
}
@@ -173,13 +173,13 @@ SRD_API int srd_log_handler_set_default(void)
return SRD_OK;
}
-static int srd_logv(void *user_data, int loglevel, const char *format,
+static int srd_logv(void *cb_data, int loglevel, const char *format,
va_list args)
{
int ret;
/* This specific log handler doesn't need the void pointer data. */
- (void)user_data;
+ (void)cb_data;
/* Only output messages of at least the selected loglevel(s). */
if (loglevel > srd_loglevel)
@@ -130,26 +130,26 @@ SRD_API char *srd_log_logdomain_get(void)
* @param handler Function pointer to the log handler function to use.
* Must not be NULL.
- * @param user_data Pointer to private data to be passed on. This can be used
- * by the caller to pass arbitrary data to the log functions.
- * This pointer is only stored or passed on by libsigrokdecode,
- * and is never used or interpreted in any way. The pointer
- * is allowed to be NULL if the caller doesn't need/want to
- * pass any data.
+ * @param cb_data Pointer to private data to be passed on. This can be used
+ * by the caller to pass arbitrary data to the log functions.
+ * This pointer is only stored or passed on by libsigrokdecode,
+ * and is never used or interpreted in any way. The pointer
+ * is allowed to be NULL if the caller doesn't need/want to
+ * pass any data.
*
* @return SRD_OK upon success, SRD_ERR_ARG upon invalid arguments.
@@ -130,26 +130,26 @@ SRD_API char *srd_log_logdomain_get(void)
return SRD_ERR_ARG;
}
- /* Note: 'user_data' is allowed to be NULL. */
+ /* Note: 'cb_data' is allowed to be NULL. */
srd_log_handler = handler;